@@ -10,7 +10,7 @@ __author__ = "Evan Spotte-Smith <ewcspottesmith@lbl.gov>"
 
 @pytest.fixture(scope="session")
 def tasks_store(test_dir):
-    return JSONStore(test_dir / "C3H4Li1O3.json.gz")
+    return JSONStore(test_dir / "C2H4.json.gz")
 
 
 @pytest.fixture(scope="session")
@@ -38,19 +38,19 @@ def spins_store():
 
 def test_charges_builder(tasks_store, mol_store, charges_store):
     builder = PartialChargesBuilder(
-        tasks_store, mol_store, charges_store, methods=["mulliken", "resp", "critic2"]
+        tasks_store, mol_store, charges_store, methods=["mulliken", "resp", "critic2", "nbo"]
     )
     builder.run()
 
-    assert charges_store.count() == 138
+    assert charges_store.count() == 86
     assert charges_store.count({"deprecated": True}) == 0
 
 
 def test_spins_builder(tasks_store, mol_store, spins_store):
     builder = PartialSpinsBuilder(
-        tasks_store, mol_store, spins_store, methods=["mulliken"]
+        tasks_store, mol_store, spins_store, methods=["mulliken", "nbo"]
     )
     builder.run()
 
-    assert spins_store.count() == 18
+    assert spins_store.count() == 19
     assert spins_store.count({"deprecated": True}) == 0
