@@ -11,7 +11,7 @@ __author__ = "Evan Spotte-Smith <ewcspottesmith@lbl.gov>"
 
 @pytest.fixture(scope="session")
 def tasks_store(test_dir):
-    return JSONStore(test_dir / "C3H4Li1O3.json.gz")
+    return JSONStore(test_dir / "C2H4.json.gz")
 
 
 @pytest.fixture(scope="session")
@@ -44,5 +44,5 @@ def test_redox_builder(tasks_store, mol_store, thermo_store, redox_store):
     builder = RedoxBuilder(tasks_store, mol_store, thermo_store, redox_store)
     builder.run()
 
-    assert redox_store.count() == 42
+    assert redox_store.count() == 22
     assert redox_store.count({"deprecated": True}) == 0
